@@ -1,4 +1,4 @@
-context("check_input_lp_nl_iv")
+context("lp_nl_iv")
 
 # Load package data
   ag_data           <- ag_data
@@ -17,10 +17,10 @@ context("check_input_lp_nl_iv")
 
 
 
-  test_that("Check whether endogenous data is a data.frame", {
+  test_that("Test whether endogenous data is a data.frame", {
     endog_data    <- as.matrix(endog_data)
 
-    expect_error(lp_nl_iv(endog_data,
+    testthat::expect_error(lp_nl_iv(endog_data,
                               lags_endog_nl           = 3,
                               shock             = instrument,
                               exog_data         = NULL,
@@ -40,8 +40,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether trend is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether trend is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -62,8 +62,8 @@ context("check_input_lp_nl_iv")
 
 
 
-  test_that("Check whether switching variable is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether switching variable is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -83,8 +83,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether use_hp is set", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether use_hp is set", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -104,8 +104,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whetherlambda is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whetherlambda is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -125,8 +125,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether gamma is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether gamma is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -146,8 +146,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether width for confidence bands is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether width for confidence bands is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -166,8 +166,8 @@ context("check_input_lp_nl_iv")
                  'Please specify a value for the width of the confidence bands.', fixed = TRUE)
   })
 
-  test_that("Check whether number of horizons is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether number of horizons is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -186,8 +186,8 @@ context("check_input_lp_nl_iv")
                  'Please specify the number of horizons.', fixed = TRUE)
   })
 
-  test_that("Check whether lag  length criterion is correctly spelled", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether lag  length criterion is correctly spelled", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = NaN,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -207,8 +207,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether lags criterion and fixed number of lags for nonlinear model is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether lags criterion and fixed number of lags for nonlinear model is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = 3,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -228,8 +228,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether maximum number of lags is given", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether maximum number of lags is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = NaN,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -248,8 +248,8 @@ context("check_input_lp_nl_iv")
                  'Please provide a maximum number of lags for the lag length criterion.', fixed = TRUE)
   })
 
-  test_that("Check whether number of horizons is positive", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether number of horizons is positive", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = NaN,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -269,8 +269,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether trend is correctly specified", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether trend is correctly specified", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = NaN,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -291,8 +291,8 @@ context("check_input_lp_nl_iv")
 
 
 
-  test_that("Check whether width of confidence bands is correctly specified", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether width of confidence bands is correctly specified", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = NaN,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -312,8 +312,8 @@ context("check_input_lp_nl_iv")
   })
 
 
-  test_that("Check whether gamma is negative number", {
-    expect_error(lp_nl_iv(endog_data,
+  test_that("Test whether gamma is negative number", {
+    testthat::expect_error(lp_nl_iv(endog_data,
                           lags_endog_nl           = NaN,
                           shock             = instrument,
                           exog_data         = NULL,
@@ -332,6 +332,29 @@ context("check_input_lp_nl_iv")
                  'Gamma has to be a positive number.', fixed = TRUE)
   })
 
+
+  test_that("Test that data is correctly specified when lag length criterion is given", {
+    testthat::expect_error(lp_nl_iv(endog_data,
+                                    lags_endog_nl     = NaN,
+                                    shock             = instrument,
+                                    exog_data         = NULL,
+                                    lags_exog         = NULL,
+                                    contemp_data      = NULL,
+                                    lags_criterion    = 'AIC',
+                                    max_lags          = 4,
+                                    trend             = 2,
+                                    confint           = 2,
+                                    hor               = 12,
+                                    switching         = switching_variable,
+                                    use_logistic      = FALSE,
+                                    lag_switching     = TRUE,
+                                    use_hp            = TRUE,
+                                    lambda            = 1600,
+                                    gamma             = 3,
+                                    num_cores         = 1),
+                           NA)
+  })
+
 # This example replicates results from the Supplementary Appendix
 # by Ramey and Zubairy (2018), based on results from their provided
 # Matlab code. The results evaluate findings from Auerbach and
@@ -353,7 +376,7 @@ context("check_input_lp_nl_iv")
   exog_data         <- as.data.frame(ag_data$GDP_MA[sample_start:sample_end])
 
 # Choose exogenous data
-  switching_variable <- ag_data$GDP_MA[sample_start:sample_end] - 0.8
+  switching_variable <- as.data.frame(ag_data$GDP_MA[sample_start:sample_end]) - 0.8
 
 
 # These results are taken from the available Matlab code by Ramey and Zubairy (2018)
@@ -380,6 +403,8 @@ test_that("Compare results with RZ-2018", {
                             confint           = 1.96,
                             hor               = 20,
                             switching         = switching_variable,
+                            use_logistic      = TRUE,
+                            lag_switching     = TRUE,
                             use_hp            = 0,
                             lambda            = NaN,
                             gamma             = 3,
